Enum bvy::shape::CapsuleUvProfile
[−]pub enum CapsuleUvProfile {
Aspect,
Uniform,
Fixed,
}Expand description
Manner in which UV coordinates are distributed vertically.
Variants
Aspect
UV space is distributed by how much of the capsule consists of the hemispheres.
Uniform
Hemispheres get UV space according to the ratio of latitudes to rings.
Fixed
Upper third of the texture goes to the northern hemisphere, middle third to the cylinder and lower third to the southern one.