pub struct Audio<Source = AudioSource> where
Source: Asset + Decodable, { /* private fields */ }Expand description
Use this resource to play audio
fn play_audio_system(asset_server: Res<AssetServer>, audio: Res<Audio>) {
audio.play(asset_server.load("my_sound.ogg"));
}Implementations
impl<Source> Audio<Source> where
Source: Asset + Decodable,
impl<Source> Audio<Source> where
Source: Asset + Decodable,
pub fn play(&self, audio_source: Handle<Source>) -> Handle<AudioSink>
pub fn play(&self, audio_source: Handle<Source>) -> Handle<AudioSink>
Play audio from a Handle to the audio source
fn play_audio_system(asset_server: Res<AssetServer>, audio: Res<Audio>) {
audio.play(asset_server.load("my_sound.ogg"));
}Returns a weak Handle to the [AudioSink]. If this handle isn’t changed to a
strong one, the sink will be detached and the sound will continue playing. Changing it
to a strong handle allows for control on the playback through the [AudioSink] asset.
fn play_audio_system(
asset_server: Res<AssetServer>,
audio: Res<Audio>,
audio_sinks: Res<Assets<AudioSink>>,
) {
// This is a weak handle, and can't be used to control playback.
let weak_handle = audio.play(asset_server.load("my_sound.ogg"));
// This is now a strong handle, and can be used to control playback.
let strong_handle = audio_sinks.get_handle(weak_handle);
}pub fn play_with_settings(
&self,
audio_source: Handle<Source>,
settings: PlaybackSettings
) -> Handle<AudioSink>
pub fn play_with_settings(
&self,
audio_source: Handle<Source>,
settings: PlaybackSettings
) -> Handle<AudioSink>
Play audio from a Handle to the audio source with PlaybackSettings that
allows looping or changing volume from the start.
fn play_audio_system(asset_server: Res<AssetServer>, audio: Res<Audio>) {
audio.play_with_settings(
asset_server.load("my_sound.ogg"),
PlaybackSettings::LOOP.with_volume(0.75),
);
}See Self::play on how to control playback once it’s started.