pub struct NonSend<'w, T> where
T: 'static, { /* private fields */ }Expand description
Shared borrow of a non-Send resource.
Only Send resources may be accessed with the Res [SystemParam]. In case that the
resource does not implement Send, this SystemParam wrapper can be used. This will instruct
the scheduler to instead run the system on the main thread so that it doesn’t send the resource
over to another thread.
Panics
Panics when used as a SystemParameter if the resource does not exist.
Use Option<NonSend<T>> instead if the resource might not always exist.
Implementations
impl<'w, T> NonSend<'w, T> where
T: 'static,
impl<'w, T> NonSend<'w, T> where
T: 'static,
pub fn is_added(&self) -> bool
pub fn is_added(&self) -> bool
Returns true if (and only if) this resource been added since the last execution of this system.
pub fn is_changed(&self) -> bool
pub fn is_changed(&self) -> bool
Returns true if (and only if) this resource been changed since the last execution of this system.