Struct bvy::TextureAtlasSprite
[−]pub struct TextureAtlasSprite {
pub color: Color,
pub index: usize,
pub flip_x: bool,
pub flip_y: bool,
pub custom_size: Option<Vec2>,
pub anchor: Anchor,
}Fields
color: Colorindex: usizeflip_x: boolflip_y: boolcustom_size: Option<Vec2>An optional custom size for the sprite that will be used when rendering, instead of the size of the sprite’s image in the atlas
anchor: AnchorImplementations
impl TextureAtlasSprite
impl TextureAtlasSprite
pub fn new(index: usize) -> TextureAtlasSprite